@@ -5,7 +5,6 @@ from __future__ import absolute_import
 from _ruamel_yaml import CParser, CEmitter   # type: ignore
 
 from ruamel.yaml.constructor import Constructor, BaseConstructor, SafeConstructor
-from ruamel.yaml.serializer import Serializer
 from ruamel.yaml.representer import Representer, SafeRepresenter, BaseRepresenter
 from ruamel.yaml.resolver import Resolver, BaseResolver
 
@@ -71,6 +70,7 @@ class CBaseDumper(CEmitter, BaseRepresenter, BaseResolver):  # type: ignore
                           explicit_start=explicit_start,
                           explicit_end=explicit_end,
                           version=version, tags=tags)
+        self._emitter = self._serializer = self._representer = self
         BaseRepresenter.__init__(self, default_style=default_style,
                                  default_flow_style=default_flow_style, dumper=self)
         BaseResolver.__init__(self, loadumper=self)
@@ -85,18 +85,20 @@ class CSafeDumper(CEmitter, SafeRepresenter, Resolver):  # type: ignore
                  version=None, tags=None, block_seq_indent=None,
                  top_level_colon_align=None, prefix_colon=None):
         # type: (StreamType, Any, Any, Any, bool, Union[None, int], Union[None, int], bool, Any, Any, Union[None, bool], Union[None, bool], Any, Any, Any, Any, Any) -> None   # NOQA
+        self._emitter = self._serializer = self._representer = self
         CEmitter.__init__(self, stream, canonical=canonical,
                           indent=indent, width=width, encoding=encoding,
                           allow_unicode=allow_unicode, line_break=line_break,
                           explicit_start=explicit_start,
                           explicit_end=explicit_end,
                           version=version, tags=tags)
+        self._emitter = self._serializer = self._representer = self
         SafeRepresenter.__init__(self, default_style=default_style,
                                  default_flow_style=default_flow_style)
         Resolver.__init__(self)
 
 
-class CDumper(CEmitter, Serializer, Representer, Resolver):  # type: ignore
+class CDumper(CEmitter, Representer, Resolver):  # type: ignore
     def __init__(self, stream,
                  default_style=None, default_flow_style=None,
                  canonical=None, indent=None, width=None,
@@ -111,6 +113,7 @@ class CDumper(CEmitter, Serializer, Representer, Resolver):  # type: ignore
                           explicit_start=explicit_start,
                           explicit_end=explicit_end,
                           version=version, tags=tags)
+        self._emitter = self._serializer = self._representer = self
         Representer.__init__(self, default_style=default_style,
                              default_flow_style=default_flow_style)
         Resolver.__init__(self)
